diff --git a/Demo/Makefile.am b/Demo/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Demo/Makefile.am
@@ -0,0 +1,44 @@
+AM_CPPFLAGS = -I$(top_srcdir)/Include
+LDADD = $(top_builddir)/Source/libklu.la
+
+EXTRA_DIST = \
+	klu_simple.out \
+	kludemo.out
+
+# Disable the .out implicit pattern rule.  Prevents GNU make from
+# adding bogus dependencies for the .out files listed above.
+%.out: %
+
+check_PROGRAMS = klu_simple kludemo kluldemo
+
+TESTS = klu_simple
+
+klu_simple_SOURCES = klu_simple.c
+
+kludemo_SOURCES = kludemo.c
+kludemo_LDADD = $(LDADD) -lcholmod -lm
+
+kluldemo_SOURCES = kluldemo.c
+kluldemo_LDADD = $(LDADD) -lcholmod -lm
+
+MATRICES = \
+	../Matrix/1c.mtx \
+	../Matrix/arrowc.mtx \
+	../Matrix/arrow.mtx \
+	../Matrix/impcol_a.mtx \
+	../Matrix/w156.mtx \
+	../Matrix/ctina.mtx
+
+check-local: kludemo kluldemo $(MATRICES)
+	-./kludemo < ../Matrix/1c.mtx
+	-./kludemo < ../Matrix/arrowc.mtx
+	-./kludemo < ../Matrix/arrow.mtx
+	-./kludemo < ../Matrix/impcol_a.mtx
+	-./kludemo < ../Matrix/w156.mtx
+	-./kludemo < ../Matrix/ctina.mtx
+	-./kluldemo < ../Matrix/1c.mtx
+	-./kluldemo < ../Matrix/arrowc.mtx
+	-./kluldemo < ../Matrix/arrow.mtx
+	-./kluldemo < ../Matrix/impcol_a.mtx
+	-./kluldemo < ../Matrix/w156.mtx
+	-./kluldemo < ../Matrix/ctina.mtx
diff --git a/Doc/Makefile.am b/Doc/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Doc/Makefile.am
@@ -0,0 +1,41 @@
+# Generating KLU_UserGuide.pdf seems to be broken, so
+# just distribute the copy that came in the tarball.
+EXTRA_DIST = \
+	ChangeLog \
+	lesser.txt \
+	palamadai_e.pdf \
+	KLU_UserGuide.pdf
+
+dist_noinst_DATA = KLU_UserGuide.tex KLU_UserGuide.bib
+pdf_DATA = KLU_UserGuide.pdf palamadai_e.pdf
+
+#SRC = \
+#	klu_h.tex \
+#	btf_h.tex \
+#	klu_simple_c.tex
+#
+#klu_h.tex: ../Include/klu.h
+#	echo '\\begin{verbatim}' > $@
+#	expand -8 $< >> $@
+#	echo '\end{verbatim}' >> $@
+#
+## FIXME:  Probably shouldn't rely on this location for btf.h.
+#btf_h.tex: /usr/include/btf.h
+#	echo '\\begin{verbatim}' > $@
+#	expand -8 $< >> $@
+#	echo '\end{verbatim}' >> $@
+#
+#klu_simple_c.tex: ../Demo/klu_simple.c
+#	echo '\\begin{verbatim}' > $@
+#	expand -8 $< >> $@
+#	echo '\end{verbatim}' >> $@
+#
+#KLU_UserGuide.pdf: KLU_UserGuide.tex KLU_UserGuide.bib $(SRC)
+#	pdflatex KLU_UserGuide
+#	bibtex KLU_UserGuide
+#	pdflatex KLU_UserGuide
+#	pdflatex KLU_UserGuide
+#
+#clean-local:
+#	-$(RM) *.aux *.bbl *.blg *.log *.toc
+#	-$(RM) $(SRC)
diff --git a/Makefile.am b/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Makefile.am
@@ -0,0 +1,3 @@
+SUBDIRS = Source User Matrix Demo Doc
+EXTRA_DIST = README.txt
+include_HEADERS = Include/klu.h Include/klu_internal.h Include/klu_version.h
diff --git a/Matrix/Makefile.am b/Matrix/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Matrix/Makefile.am
@@ -0,0 +1,11 @@
+dist_noinst_DATA = \
+	1c.mtx \
+	GD99_cc.mtx \
+	arrow.mtx \
+	arrowc.mtx \
+	ctina.mtx \
+	impcol_a.mtx \
+	one.mtx \
+	onec.mtx \
+	two.mtx \
+	w156.mtx
diff --git a/Source/Makefile.am b/Source/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Source/Makefile.am
@@ -0,0 +1,40 @@
+AM_CPPFLAGS = -I$(top_srcdir)/Include
+
+noinst_LTLIBRARIES = libklud.la libkluz.la libklul.la libkluzl.la
+
+KLUSRC = \
+	klu.c \
+	klu_diagnostics.c \
+	klu_dump.c \
+	klu_extract.c \
+	klu_factor.c \
+	klu_free_numeric.c \
+	klu_kernel.c \
+	klu_refactor.c \
+	klu_scale.c \
+	klu_solve.c \
+	klu_sort.c \
+	klu_tsolve.c
+
+CKLUSRC = \
+	klu_analyze.c \
+	klu_analyze_given.c \
+	klu_defaults.c \
+	klu_free_symbolic.c \
+	klu_memory.c
+
+libklud_la_SOURCES = $(KLUSRC) $(CKLUSRC)
+
+libkluz_la_SOURCES = $(KLUSRC)
+libkluz_la_CPPFLAGS = $(AM_CPPFLAGS) -DCOMPLEX
+
+libklul_la_SOURCES = $(KLUSRC) $(CKLUSRC)
+libklul_la_CPPFLAGS = $(AM_CPPFLAGS) -DDLONG
+
+libkluzl_la_SOURCES = $(KLUSRC)
+libkluzl_la_CPPFLAGS = $(AM_CPPFLAGS) -DDLONG -DCOMPLEX
+
+lib_LTLIBRARIES = libklu.la
+libklu_la_SOURCES =
+libklu_la_LIBADD = libklud.la libkluz.la libklul.la libkluzl.la -lamd -lbtf -lcolamd
+libklu_la_LDFLAGS = -no-undefined -version-info 2:1:1
diff --git a/User/Makefile.am b/User/Makefile.am
new file mode 100644
--- /dev/null
+++ b/User/Makefile.am
@@ -0,0 +1,9 @@
+AM_CPPFLAGS = -I$(top_srcdir)/Include
+
+EXTRA_DIST = README.txt
+
+include_HEADERS = klu_cholmod.h
+lib_LTLIBRARIES = libklu_cholmod.la
+libklu_cholmod_la_SOURCES = klu_cholmod.c klu_l_cholmod.c
+libklu_cholmod_la_LIBADD = -lcholmod
+libklu_cholmod_la_LDFLAGS = -no-undefined -version-info 2:1:1
diff --git a/configure.ac b/configure.ac
new file mode 100644
--- /dev/null
+++ b/configure.ac
@@ -0,0 +1,35 @@
+AC_PREREQ([2.65])
+AC_INIT([KLU], [1.1.1], [davis@cise.ufl.edu])
+AC_CONFIG_SRCDIR([Source/klu.c])
+AC_CONFIG_HEADER([config.h])
+AM_INIT_AUTOMAKE([foreign])
+LT_INIT
+
+AC_PROG_INSTALL
+AC_PROG_CC
+
+LIBS_SAVED=$LIBS
+
+AC_CHECK_LIB([m], [sqrt])
+AC_CHECK_LIB([amd], [amd_order])
+AC_CHECK_LIB([btf], [btf_order])
+AC_CHECK_LIB([colamd], [colamd_recommended])
+AC_CHECK_LIB([cholmod], [cholmod_start])
+
+AC_CHECK_HEADERS([limits.h stdlib.h])
+AC_CHECK_HEADERS([UFconfig.h])
+
+AC_TYPE_SIZE_T
+
+AC_CHECK_FUNCS([sqrt])
+
+LIBS=$LIBS_SAVED
+
+AC_CONFIG_FILES([
+	Makefile
+	Demo/Makefile
+	Doc/Makefile
+	Matrix/Makefile
+	Source/Makefile
+	User/Makefile])
+AC_OUTPUT
